@@ -8,21 +8,13 @@
   
 
 package Net::OpenNebula::Cluster;
-
+$Net::OpenNebula::Cluster::VERSION = '0.2';
 use strict;
 use warnings;
 
-use Data::Dumper;
-
-sub new {
-   my $that = shift;
-   my $proto = ref($that) || $that;
-   my $self = { @_ };
-
-   bless($self, $proto);
-
-   return $self;
-}
+use Net::OpenNebula::RPC;
+push our @ISA , qw(Net::OpenNebula::RPC);
 
+use constant ONERPC => 'cluster';
 
 1;
