@@ -28,26 +28,14 @@ Query the Hoststatus of an OpenNebula host.
 =cut
 
 package Net::OpenNebula::Host;
-
+$Net::OpenNebula::Host::VERSION = '0.2';
 use strict;
 use warnings;
 
-use Data::Dumper;
+use Net::OpenNebula::RPC;
+push our @ISA , qw(Net::OpenNebula::RPC);
 
-sub new {
-   my $that = shift;
-   my $proto = ref($that) || $that;
-   my $self = { @_ };
-
-   bless($self, $proto);
-
-   return $self;
-}
-
-sub id {
-   my ($self) = @_;
-   return $self->{data}->{ID}->[0];
-}
+use constant ONERPC => 'host';
 
 sub name {
    my ($self) = @_;
@@ -56,14 +44,6 @@ sub name {
    return $self->{extended_data}->{NAME}->[0];
 }
 
-sub _get_info {
-   my ($self) = @_;
-
-   if(! exists $self->{extended_data}) {
-      $self->{extended_data} = $self->{rpc}->_rpc("one.host.info", [ int => $self->id ]);
-   }
-}
-
 sub vms {
    my ($self) = @_;
    $self->_get_info();
@@ -75,4 +55,12 @@ sub vms {
    return @ret;
 }
 
+sub used {
+   my ($self) = @_;
+   $self->_get_info();
+   if ($self->{extended_data}->{HOST_SHARE}->[0]->{RUNNING_VMS}->[0]) {
+       return 1;
+   } 
+};
+
 1;
