@@ -1,27 +1,35 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
-#
+# 
 # vim: set ts=3 sw=3 tw=0:
 # vim: set expandtab:
 #
+   
+
+package Net::OpenNebula::Image;
+$Net::OpenNebula::Image::VERSION = '0.2';
 use strict;
 use warnings;
 
-package Net::OpenNebula::Image;
-$Net::OpenNebula::Image::VERSION = '0.317.0';
 use Net::OpenNebula::RPC;
 push our @ISA , qw(Net::OpenNebula::RPC);
 
 use constant ONERPC => 'image';
-use constant NAME_FROM_TEMPLATE => 1;
 
 # from include/Image.h enum ImageState
 use constant STATES => qw(INIT READY USED DISABLED LOCKED ERROR CLONE DELETE USED_PERS);
 
+sub name {
+   my ($self) = @_;
+   $self->_get_info();
+
+   return $self->{extended_data}->{NAME}->[0];
+}
+
 sub create {
    my ($self, $tpl_txt, $datastoreid) = @_;
    my $id = $self->_onerpc("allocate", [ string => $tpl_txt ], [ int => $datastoreid ]);
-   $self->{data} =  $self->_get_info(id => $id);
+   $self->{data} =  $self->_get_info(id => $id); 
    return $id;
 }
 
@@ -37,13 +45,7 @@ sub state {
    $self->_get_info(clearcache => 1);
 
    my $state = $self->{extended_data}->{STATE}->[0];
-
-   if(!defined($state)) {
-       $self->warn('Undefined '.ONERPC.'-state for id ', $self->id);
-       return;
-   }
-
-   return (STATES)[$state];
+   return (STATES)[$state];    
 };
 
 
